#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 czipwith
version:              1.0.1.3
visibility:           public
id:                   czipwith-1.0.1.3-Ii3Y982EHXkETaxSaL3WC3
key:                  czipwith-1.0.1.3-Ii3Y982EHXkETaxSaL3WC3
license:              BSD-3-Clause
copyright:            Copyright (C) 2017-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/czipwith/
synopsis:             CZipWith class and deriving via TH
description:
    A typeclass similar to Data.Distributive, but for
    data parameterised with a type constructor. The name
    comes from the resemblance of its method to the regular
    zipWith function. The abstraction is useful for example
    for program config handling.

category:             Data
abi:                  ee1a1d2c2d6cdadaf97a0c8e65837512
exposed:              True
exposed-modules:      Data.CZipWith
import-dirs:          /usr/lib/ghc-8.10.5/site-local/czipwith-1.0.1.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/czipwith-1.0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/czipwith-1.0.1.3
hs-libraries:         HSczipwith-1.0.1.3-Ii3Y982EHXkETaxSaL3WC3
depends:              base-4.14.2.0 template-haskell-2.16.0.0
haddock-interfaces:   /usr/share/doc/haskell-czipwith/html/czipwith.haddock
haddock-html:         /usr/share/doc/haskell-czipwith/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

